@@ -10,9 +10,10 @@ def news():
         Client.close()
         soup_page = soup(xml_page, "xml")
         news_list = soup_page.findAll("item")
-        # for news in news_list[:15]:
-        #     return news.title.text.encode('utf-8')
-        return news_list
+        li = []
+        for news in news_list[:15]:
+            li.append(str(news.title.text.encode('utf-8'))[1:])
+        return li
     except Exception as e:
         print(e)
         return False
\ No newline at end of file
